Index: include/v8-debug.h |
=================================================================== |
--- include/v8-debug.h (revision 7267) |
+++ include/v8-debug.h (working copy) |
@@ -227,7 +227,7 @@ |
* Debug message callback function. |
* |
* \param message the debug message handler message object |
- |
+ * |
* A MessageHandler does not take possession of the message data, |
* and must not rely on the data persisting after the handler returns. |
*/ |
@@ -253,17 +253,23 @@ |
static bool SetDebugEventListener(v8::Handle<v8::Object> that, |
Handle<Value> data = Handle<Value>()); |
- // Schedule a debugger break to happen when JavaScript code is run. |
- static void DebugBreak(); |
+ // Schedule a debugger break to happen when JavaScript code is run |
+ // in the given isolate. If no isolate is provided the default |
+ // isolate is used. |
+ static void DebugBreak(Isolate* isolate = NULL); |
- // Remove scheduled debugger break if it has not happened yet. |
- static void CancelDebugBreak(); |
+ // Remove scheduled debugger break in given isolate if it has not |
+ // happened yet. If no isolate is provided the default isolate is |
+ // used. |
+ static void CancelDebugBreak(Isolate* isolate = NULL); |
- // Break execution of JavaScript (this method can be invoked from a |
- // non-VM thread) for further client command execution on a VM |
- // thread. Client data is then passed in EventDetails to |
- // EventCallback at the moment when the VM actually stops. |
- static void DebugBreakForCommand(ClientData* data = NULL); |
+ // Break execution of JavaScript in the given isolate (this method |
+ // can be invoked from a non-VM thread) for further client command |
+ // execution on a VM thread. Client data is then passed in |
+ // EventDetails to EventCallback at the moment when the VM actually |
+ // stops. If no isolate is provided the default isolate is used. |
+ static void DebugBreakForCommand(ClientData* data = NULL, |
+ Isolate* isolate = NULL); |
// Message based interface. The message protocol is JSON. NOTE the message |
// handler thread is not supported any more parameter must be false. |